@@ -1,7 +1,7 @@
 /*
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2018 Kern Sibbald
+   Copyright (C) 2000-2020 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
@@ -251,7 +251,7 @@ inline char *CAT::name() const { return hdr.name; }
 class CLIENT_GLOBALS {
 public:
    dlink link;                        /* double link */
-   const char *name;                  /* resource name */
+   char *name;                        /* resource name */
    int32_t NumConcurrentJobs;         /* number of concurrent jobs running */
    char *SetIPaddress;                /* address from SetIP command */
    int enabled;                       /* -1: not set, 0 disabled, 1 enabled */
@@ -306,7 +306,7 @@ inline char *CLIENT::name() const { return hdr.name; }
 class STORE_GLOBALS {
 public:
    dlink link;                        /* double link */
-   const char *name;                  /* resource name */
+   char *name;                        /* resource name */
    int32_t NumConcurrentJobs;         /* number of concurrent jobs running */
    int32_t NumConcurrentReadJobs;     /* number of concurrent read jobs running */
    int enabled;                       /* -1: not set, 0: disabled, 1: enabled */
@@ -406,7 +406,7 @@ inline void USTORE::set_source(const char *where)
 class JOB_GLOBALS {
 public:
    dlink link;                        /* double link */
-   const char *name;                  /* resource name */
+   char *name;                        /* resource name */
    int32_t NumConcurrentJobs;         /* number of concurrent jobs running */
    int enabled;                       /* -1: disabled, 0: disabled, 1: Enabled */
 };
@@ -608,7 +608,7 @@ inline char *FILESET::name() const { return hdr.name; }
 class SCHED_GLOBALS {
 public:
    dlink link;                        /* double link */
-   const char *name;                  /* resource name */
+   char *name;                        /* resource name */
    int enabled;                       /* -1: not set, 0: disabled, 1: Enabled */
 };
 
