@@ -290,7 +290,7 @@ extern "C" HANDLE get_osfhandle(int fd);
 
 void binit(BFILE *bfd)
 {
-   memset(bfd, 0, sizeof(BFILE));
+   memset((void *)bfd, 0, sizeof(BFILE));
    bfd->fid = -1;
    bfd->mode = BF_CLOSED;
    bfd->use_backup_api = have_win32_api();
@@ -880,7 +880,7 @@ boffset_t blseek(BFILE *bfd, boffset_t offset, int whence)
 /* Unix */
 void binit(BFILE *bfd)
 {
-   memset(bfd, 0, sizeof(BFILE));
+   memset((void *)bfd, 0, sizeof(BFILE));
    bfd->fid = -1;
 }
 
