@@ -1,29 +1,20 @@
 /*
-   Bacula® - The Network Backup Solution
+   Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2007 Free Software Foundation Europe e.V.
+   Copyright (C) 2000-2020 Kern Sibbald
 
-   The main author of Bacula is Kern Sibbald, with contributions from
-   many others, a complete list can be found in the file AUTHORS.
-   This program is Free Software; you can redistribute it and/or
-   modify it under the terms of version three of the GNU Affero General Public
-   License as published by the Free Software Foundation and included
-   in the file LICENSE.
+   The original author of Bacula is Kern Sibbald, with contributions
+   from many others, a complete list can be found in the file AUTHORS.
 
-   This program is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-   General Public License for more details.
+   You may use this file and others of this release according to the
+   license defined in the LICENSE file, which includes the Affero General
+   Public License, v3.0 ("AGPLv3") and some additional permissions and
+   terms pursuant to its AGPLv3 Section 7.
 
-   You should have received a copy of the GNU Affero General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   This notice must be preserved when any source code is 
+   conveyed and/or propagated.
 
-   Bacula® is a registered trademark of Kern Sibbald.
-   The licensor of Bacula is the Free Software Foundation Europe
-   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
-   Switzerland, email:ftf@fsfeurope.org.
+   Bacula(R) is a registered trademark of Kern Sibbald.
 */
 /*
  *   lex.h
@@ -32,8 +23,6 @@
  *
  *   Kern Sibbald, MM
  *
- *   Version $Id$
- *
  */
 
 #ifndef _LEX_H
@@ -89,7 +78,7 @@ enum lex_state {
    lex_quoted_string,
    lex_include_quoted_string,
    lex_include,
-   lex_utf8_bom,      /* we are parsing out a utf8 byte order mark */ 
+   lex_utf8_bom,      /* we are parsing out a utf8 byte order mark */
    lex_utf16_le_bom   /* we are parsing out a utf-16 (little endian) byte order mark */
 };
 
@@ -97,17 +86,18 @@ enum lex_state {
 #define LOPT_NO_IDENT            0x1  /* No Identifiers -- use string */
 #define LOPT_STRING              0x2  /* Force scan for string */
 #define LOPT_NO_EXTERN           0x4  /* Don't follow @ command */
+#define LOPT_NO_MD5              0x8  /* Do not encode passwords with MD5 */
 
 class BPIPE;                          /* forward reference */
-  
+
 /* Lexical context */
 typedef struct s_lex_context {
    struct s_lex_context *next;        /* pointer to next lexical context */
    int options;                       /* scan options */
    char *fname;                       /* filename */
    FILE *fd;                          /* file descriptor */
-   char line[MAXSTRING];              /* input line */
-   char str[MAXSTRING];               /* string being scanned */
+   POOLMEM *line;                     /* input line */
+   POOLMEM *str;                      /* string being scanned */
    int str_len;                       /* length of string */
    int line_no;                       /* file line number */
    int col_no;                        /* char position on line */
@@ -140,5 +130,6 @@ typedef void (LEX_ERROR_HANDLER)(const char *file, int line, LEX *lc, const char
 
 void scan_to_eol(LEX *lc);
 int scan_to_next_not_eol(LEX * lc);
+void lex_store_clear_passwords(LEX *lf);
 
 #endif /* _LEX_H */
