@@ -1,7 +1,7 @@
 /*
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2018 Kern Sibbald
+   Copyright (C) 2000-2020 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
@@ -27,6 +27,10 @@
 #include "cloud_transfer_mgr.h"
 #include "stored.h"
 
+#define ONE_SEC 1000000LL /* number of microseconds in a second */
+
+static const int dbglvl = 450;
+
 /* constructor
    * size : the size in bytes of the transfer
    * funct : function to process
@@ -46,9 +50,11 @@ transfer::transfer(uint64_t    size,
                   DCR          *dcr,
                   cloud_proxy  *proxy) :
    m_stat_size(size),
+   m_stat_processed_size(0),
    m_stat_start(0),
    m_stat_duration(0),
    m_stat_eta(0),
+   m_stat_average_rate(0),
    m_message(NULL),
    m_state(TRANS_STATE_CREATED),
    m_mgr(NULL),
@@ -84,7 +90,7 @@ transfer::~transfer()
    free(m_cache_fname);
    if (m_use_count > 0) {
       ASSERT(FALSE);
-      Dmsg1(0, "!!!m_use_count = %d\n", m_use_count);
+      Dmsg1(dbglvl, "!!!m_use_count = %d\n", m_use_count);
    }
 }
 
@@ -98,6 +104,31 @@ bool transfer::queue()
    return true;
 }
 
+/* reset processed size */
+void transfer::reset_processed_size()
+{
+   lock_guard lg(m_stat_mutex);
+   m_stat_processed_size = 0;
+   ASSERTD(m_stat_processed_size==0, "invalid locking of processed size");
+}
+
+/* set absolute value process size */
+void transfer::set_processed_size(uint64_t size)
+{
+   lock_guard lg(m_stat_mutex);
+   m_stat_processed_size = size;
+   m_stat_duration = get_current_btime()-m_stat_start;
+   if (m_stat_duration > 0) {
+      m_stat_average_rate = (m_stat_processed_size*ONE_SEC)/m_stat_duration;
+   }
+   ASSERTD(m_stat_processed_size <= m_stat_size, "increment_processed_size increment too big");
+
+}
+/* add increment to the current processed size */
+void transfer::increment_processed_size(uint64_t increment)
+{
+   set_processed_size(m_stat_processed_size+increment);
+}
 
 /* opaque function that processes m_funct with m_arg as parameter
  * depending on m_funct return value, changes state to TRANS_STATE_DONE
@@ -166,7 +197,7 @@ bool transfer::cancel()
 }
 
 /* checking the cancel status : doesnt request locking */
-bool transfer::is_cancelled() const
+bool transfer::is_canceled() const
 {
    return m_cancel;
 }
@@ -178,21 +209,22 @@ uint32_t transfer::append_status(POOL_MEM& msg)
    uint32_t ret=0;
    static const char *state[]  = {"created",  "queued",  "process", "done", "error"};
 
+   lock_guard lg(m_stat_mutex);
    if (m_state > TRANS_STATE_PROCESSED) {
       ret =  Mmsg(tmp_msg,_("%s/part.%-5d state=%-7s size=%sB duration=%ds%s%s\n"),
                   m_volume_name, m_part,
                   state[m_state],
                   edit_uint64_with_suffix(m_stat_size, ec),
-                  m_stat_duration,
+                  m_stat_duration/ONE_SEC,
                   (strlen(m_message) != 0)?" msg=":"",
                   (strlen(m_message) != 0)?m_message:"");
       pm_strcat(msg, tmp_msg);
    } else {
-      ret = Mmsg(tmp_msg,_("%s/part.%-5d, state=%-7s size=%sB eta=%dss%s%s\n"),
+      ret = Mmsg(tmp_msg,_("%s/part.%-5d state=%-7s size=%sB eta=%ds%s%s\n"),
                   m_volume_name, m_part,
                   state[m_state],
                   edit_uint64_with_suffix(m_stat_size, ec),
-                  m_stat_eta,
+                  m_stat_eta/ONE_SEC,
                   (strlen(m_message) != 0)?" msg=":"",
                   (strlen(m_message) != 0)?m_message:"");
       pm_strcat(msg, tmp_msg);
@@ -201,6 +233,34 @@ uint32_t transfer::append_status(POOL_MEM& msg)
    return ret;
 }
 
+void transfer::append_api_status(OutputWriter &ow)
+{
+   static const char *state[]  = {"created",  "queued",  "process", "done", "error"};
+
+   lock_guard lg(m_stat_mutex);
+   if (m_state > TRANS_STATE_PROCESSED) {
+         ow.get_output(OT_START_OBJ,
+                  OT_STRING,"volume_name",            m_volume_name,
+                  OT_INT32, "part",                   m_part,
+                  OT_INT32, "jobid",                  m_dcr->jcr->JobId,
+                  OT_STRING,"state",                  state[m_state],
+                  OT_INT64, "size",                   m_stat_size,
+                  OT_DURATION, "duration",            m_stat_duration/ONE_SEC,
+                  OT_STRING,"message",                m_message,
+                  OT_END);
+   } else {
+         ow.get_output(OT_START_OBJ,
+                  OT_STRING,"volume_name",            m_volume_name,
+                  OT_INT32, "part",                   m_part,
+                  OT_INT32, "jobid",                  m_dcr->jcr->JobId,
+                  OT_STRING,"state",                  state[m_state],
+                  OT_INT64, "size",                   m_stat_size,
+                  OT_INT64, "processed_size",         m_stat_processed_size,
+                  OT_DURATION, "eta",                 m_stat_eta/ONE_SEC,
+                  OT_STRING,"message",                m_message,
+                  OT_END);
+   }
+}
 
 /* the manager references itself through this function */
 void transfer::set_manager(transfer_manager *mgr)
@@ -235,7 +295,6 @@ bool transfer::transition(transfer_state state)
                V(m_mgr->m_stat_mutex);
 
                P(m_mgr->m_mutex);
-               ++m_use_count;
                m_mgr->add_work(this);
                V(m_mgr->m_mutex);
             }
@@ -259,7 +318,6 @@ bool transfer::transition(transfer_state state)
 
                P(m_mgr->m_mutex);
                m_mgr->remove_work(m_workq_elem);
-               --m_use_count;
                V(m_mgr->m_mutex);
             }
          }
@@ -283,7 +341,7 @@ bool transfer::transition(transfer_state state)
 
                /*transfer starts now*/
                P(m_stat_mutex);
-               m_stat_start = (utime_t)time(NULL);
+               m_stat_start = get_current_btime();
                V(m_stat_mutex);
             }
          }
@@ -296,7 +354,12 @@ bool transfer::transition(transfer_state state)
             ret = true;
             /*transfer stops now : compute transfer duration*/
             P(m_stat_mutex);
-            m_stat_duration = (utime_t)time(NULL)-m_stat_start;
+            m_stat_duration = get_current_btime()-m_stat_start;
+            if (m_stat_duration > 0) {
+               m_stat_processed_size = m_stat_size;
+               ASSERTD(m_stat_size == m_stat_processed_size, "xfer done before processed size is equal to size.");
+               m_stat_average_rate = (m_stat_size*ONE_SEC)/m_stat_duration;
+            }
             V(m_stat_mutex);
 
             if (m_mgr) {
@@ -309,17 +372,8 @@ bool transfer::transition(transfer_state state)
                m_mgr->m_stat_size_done += m_stat_size;
                /*add local duration to manager duration */
                m_mgr->m_stat_duration_done += m_stat_duration;
-               /*reprocess the manager average rate with it*/
-               if (m_mgr->m_stat_duration_done != 0) {
-                  m_mgr->m_stat_average_rate =
-                        m_mgr->m_stat_size_done /
-                        m_mgr->m_stat_duration_done;
-               }
                /*unlock manager statistics */
                V(m_mgr->m_stat_mutex);
-
-               /* process is completed, unref the workq reference */
-               --m_use_count;
             }
 
             if (m_proxy) {
@@ -335,7 +389,7 @@ bool transfer::transition(transfer_state state)
             ret = true;
             /*transfer stops now, even if in error*/
             P(m_stat_mutex);
-            m_stat_duration = (utime_t)time(NULL)-m_stat_start;
+            m_stat_duration = get_current_btime()-m_stat_start;
             V(m_stat_mutex);
 
             if (m_mgr) {
@@ -348,9 +402,6 @@ bool transfer::transition(transfer_state state)
                m_mgr->m_stat_size_error += m_stat_size;
                /*unlock manager statistics */
                V(m_mgr->m_stat_mutex);
-
-               /* process is completed, unref the workq reference */
-               --m_use_count;
             }
             /* in both case, success or failure, life keeps going on */
             pthread_cond_broadcast(&m_done);
@@ -569,44 +620,44 @@ bool transfer_manager::find(const char *VolName, uint32_t index)
 void transfer_manager::update_statistics()
 {
    /* lock the manager stats */
-   P(m_stat_mutex);
-
-   /* ETA naive calculation for each element in the queue =
-    * (accumulator(previous elements size) / average_rate) / num_workers;
-    */
-   uint64_t accumulator=0;
+   lock_guard lg_stat(m_stat_mutex);
 
    /* lock the queue so order and chaining cannot be modified */
-   P(m_mutex);
-   P(m_wq.mutex);
-   m_stat_nb_workers = m_wq.max_workers;
+   lock_guard lg(m_mutex);
 
-   /* parse the queued and processed transfers */
+   /* recompute global average rate */
    transfer *t;
+   uint64_t accumulated_done_average_rate = 0;
+   uint32_t nb_done_accumulated = 0;
    foreach_dlist(t, &m_transfer_list) {
-      if ( (t->m_state == TRANS_STATE_QUEUED) ||
-            (t->m_state == TRANS_STATE_PROCESSED)) {
-         accumulator+=t->m_stat_size;
-         P(t->m_stat_mutex);
-         if ((m_stat_average_rate != 0) &&  (m_stat_nb_workers != 0)) {
-            /*update eta for each transfer*/
-            t->m_stat_eta = (accumulator / m_stat_average_rate) / m_stat_nb_workers;
+      lock_guard lg_xferstatmutex(t->m_stat_mutex);
+      if (t->m_stat_average_rate>0) {
+         accumulated_done_average_rate += t->m_stat_average_rate;
+         t->m_stat_average_rate = 0;
+         ++nb_done_accumulated;
+      }
+   }
+   if (nb_done_accumulated) {
+      m_stat_average_rate = accumulated_done_average_rate / nb_done_accumulated;
+   }
+
+   /* ETA naive calculation for each element in the queue */
+   if (m_stat_average_rate != 0) {
+      uint64_t accumulator=0;
+      foreach_dlist(t, &m_transfer_list) {
+         if (t->m_state == TRANS_STATE_QUEUED) {
+            lock_guard lg_xferstatmutex(t->m_stat_mutex);
+            accumulator+= t->m_stat_size-t->m_stat_processed_size;
+            t->m_stat_eta = (accumulator / m_stat_average_rate) * ONE_SEC;
+         }
+         if (t->m_state == TRANS_STATE_PROCESSED) {
+            lock_guard lg_xferstatmutex(t->m_stat_mutex);
+            t->m_stat_eta = ((t->m_stat_size-t->m_stat_processed_size) / m_stat_average_rate) * ONE_SEC;
          }
-         V(t->m_stat_mutex);
       }
+      /* the manager ETA is the ETA of the last transfer in its workq */
+      m_stat_eta = (accumulator / m_stat_average_rate) * ONE_SEC;
    }
-
-   /* the manager ETA is the ETA of the last transfer in its workq */
-   if (m_wq.last) {
-      transfer *t = (transfer *)m_wq.last->data;
-      if (t) {
-         m_stat_eta = t->m_stat_eta;
-      }
-   }
-
-   V(m_wq.mutex);
-   V(m_mutex);
-   V(m_stat_mutex);
 }
 
 /* short status of the transfers */
@@ -615,9 +666,10 @@ uint32_t transfer_manager::append_status(POOL_MEM& msg, bool verbose)
    update_statistics();
    char ec0[30],ec1[30],ec2[30],ec3[30],ec4[30];
    POOLMEM *tmp_msg = get_pool_memory(PM_MESSAGE);
+   lock_guard lg_stat(m_stat_mutex);
    uint32_t ret = Mmsg(tmp_msg, _("(%sB/s) (ETA %d s) "
             "Queued=%d %sB, Processed=%d %sB, Done=%d %sB, Failed=%d %sB\n"),
-            edit_uint64_with_suffix(m_stat_average_rate, ec0), m_stat_eta,
+            edit_uint64_with_suffix(m_stat_average_rate, ec0), m_stat_eta/ONE_SEC,
             m_stat_nb_transfer_queued,  edit_uint64_with_suffix(m_stat_size_queued, ec1),
             m_stat_nb_transfer_processed,  edit_uint64_with_suffix(m_stat_size_processed, ec2),
             m_stat_nb_transfer_done,  edit_uint64_with_suffix(m_stat_size_done, ec3),
@@ -625,7 +677,7 @@ uint32_t transfer_manager::append_status(POOL_MEM& msg, bool verbose)
    pm_strcat(msg, tmp_msg);
 
    if (verbose) {
-      P(m_mutex);
+      lock_guard lg(m_mutex);
       if (!m_transfer_list.empty()) {
          ret += Mmsg(tmp_msg, _("------------------------------------------------------------ details ------------------------------------------------------------\n"));
          pm_strcat(msg, tmp_msg);
@@ -634,8 +686,36 @@ uint32_t transfer_manager::append_status(POOL_MEM& msg, bool verbose)
       foreach_dlist(tpkt, &m_transfer_list) {
          ret += tpkt->append_status(msg);
       }
-      V(m_mutex);
    }
    free_pool_memory(tmp_msg);
    return ret;
 }
+
+void transfer_manager::append_api_status(OutputWriter &ow, bool verbose)
+{
+   update_statistics();
+
+   lock_guard lg_stat(m_stat_mutex);
+   ow.get_output(OT_START_OBJ,
+                  OT_INT64, "average_rate",           m_stat_average_rate,
+                  OT_DURATION, "eta",                 m_stat_eta/ONE_SEC,
+                  OT_INT64, "nb_transfer_queued",     m_stat_nb_transfer_queued,
+                  OT_INT64, "size_queued",            m_stat_size_queued,
+                  OT_INT64, "nb_transfer_processed",  m_stat_nb_transfer_processed,
+                  OT_INT64, "size_processed",         m_stat_size_processed,
+                  OT_INT64, "nb_transfer_done",       m_stat_nb_transfer_done,
+                  OT_INT64, "size_done",              m_stat_size_done,
+                  OT_INT64, "nb_transfer_error",      m_stat_nb_transfer_error,
+                  OT_INT64, "size_error",             m_stat_size_error,
+                  OT_INT,   "transfers_list_size",    m_transfer_list.size(),
+                  OT_END);
+   if (verbose) {
+      lock_guard lg(m_mutex);
+      ow.start_list("transfers");
+      transfer *tpkt;
+      foreach_dlist(tpkt, &m_transfer_list) {
+         tpkt->append_api_status(ow);
+      }
+      ow.end_list();
+   }
+}
