@@ -100,8 +100,8 @@ public:
    transfer_engine     *m_funct;
 
    /* variables */
-   const char          *m_cache_fname;
-   const char          *m_volume_name;
+   char                *m_cache_fname;
+   char                *m_volume_name;
    uint32_t             m_part;
    cloud_driver        *m_driver;
    DCR                 *m_dcr;
