@@ -1,7 +1,7 @@
 /*
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2017 Kern Sibbald
+   Copyright (C) 2000-2020 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
@@ -905,7 +905,7 @@ static bool upload_cmd(JCR *jcr)
             dev->setVolCatName(volname);
             dev->part = 0;
             if (dev->open_device(dcr, OPEN_READ_WRITE)) {
-               ok = dev->upload_cache(dcr, volname, err);
+               ok = dev->upload_cache(dcr, volname, 0, err);
                dev->part = 0;
                dev->close(dcr);
                dev->end_of_job(dcr, TRUNC_CONF_DEFAULT);
@@ -917,7 +917,7 @@ static bool upload_cmd(JCR *jcr)
             dev->setVolCatName(volname);
             dev->part = 0;
             if (dev->open_device(dcr, OPEN_READ_WRITE)) {
-               ok = dev->upload_cache(dcr, volname, err);
+               ok = dev->upload_cache(dcr, volname, 0, err);
                dev->part = 0;
                dev->close(dcr);
                dev->end_of_job(dcr, TRUNC_CONF_DEFAULT);
