@@ -1,7 +1,7 @@
 /*
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2018 Kern Sibbald
+   Copyright (C) 2000-2020 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
@@ -69,8 +69,12 @@ bool do_vbackup(JCR *jcr)
 
    Dmsg1(20, "Start read data. newbsr=%d\n", jcr->use_new_match_all);
 
-   if (!jcr->read_dcr || !jcr->dcr) {
-      Jmsg(jcr, M_FATAL, 0, _("Read and write devices not properly initialized.\n"));
+   if (!jcr->read_dcr) {
+      Jmsg(jcr, M_FATAL, 0, _("Read device not initialized or defined for this job.\n"));
+      goto bail_out;
+   }
+   if (!jcr->dcr) {
+      Jmsg(jcr, M_FATAL, 0, _("Write device not initialized or defined for this job.\n"));
       goto bail_out;
    }
    Dmsg2(100, "read_dcr=%p write_dcr=%p\n", jcr->read_dcr, jcr->dcr);
