@@ -2892,20 +2892,6 @@ void LogErrorMsg(const char *message)
    }
 }
 
-/*
- * Don't allow OS to suspend while backup running
- *   Note, the OS automatically tracks these for each thread
- */
-void prevent_os_suspensions()
-{
-   SetThreadExecutionState(ES_CONTINUOUS | ES_SYSTEM_REQUIRED);
-}
-
-void allow_os_suspensions()
-{
-   SetThreadExecutionState(ES_CONTINUOUS);
-}
-
 int mkstemp(char *t)
 {
    char *filename = mktemp(t);
@@ -2934,6 +2920,9 @@ uint64_t get_memory_info(char *buf, int buflen)
    uint64_t ret=0;
    HANDLE hProcess = GetCurrentProcess();
    PROCESS_MEMORY_COUNTERS pmc;
+   if (!buf) {
+      return ret;
+   }
    buf[0] = '\0';
 
    if (p_GetProcessMemoryInfo) {
