@@ -1,32 +1,23 @@
 /*
-   Bacula® - The Network Backup Solution
+   Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2010-2011 Bacula Systems(R) SA
+   Copyright (C) 2000-2018 Kern Sibbald
 
-   The main author of Bacula is Kern Sibbald, with contributions from
-   many others, a complete list can be found in the file AUTHORS.
-   This program is Free Software; you can redistribute it and/or
-   modify it under the terms of version three of the GNU Affero General Public
-   License as published by the Free Software Foundation, which is 
-   listed in the file LICENSE.
+   The original author of Bacula is Kern Sibbald, with contributions
+   from many others, a complete list can be found in the file AUTHORS.
 
-   This program is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-   General Public License for more details.
+   You may use this file and others of this release according to the
+   license defined in the LICENSE file, which includes the Affero General
+   Public License, v3.0 ("AGPLv3") and some additional permissions and
+   terms pursuant to its AGPLv3 Section 7.
 
-   You should have received a copy of the GNU Affero General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   This notice must be preserved when any source code is
+   conveyed and/or propagated.
 
-   Bacula® is a registered trademark of Kern Sibbald.
-   The licensor of Bacula is the Free Software Foundation Europe
-   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
-   Switzerland, email:ftf@fsfeurope.org.
+   Bacula(R) is a registered trademark of Kern Sibbald.
 */
 /* 
- *  Written by James Harper, October 2008
+ *  Written by James Harper, July 2010
  */
 
 #ifndef _EXCHANGE_FD_H
@@ -44,7 +35,7 @@
 
 #if defined(HAVE_WIN32)
 #if defined(HAVE_MINGW)
-#include "mingwconfig.h"
+#include "winhdrs.h"
 #else
 #include "winconfig.h"
 #endif
@@ -91,8 +82,7 @@ enum {
 #endif
 
 //#include "bacula.h"
-#include <windows.h>
-#include "win32/compat/compat.h"
+#include "compat.h"
 #include "bc_types.h"
 
 typedef int64_t   boffset_t;
@@ -100,10 +90,10 @@ typedef int64_t   boffset_t;
 #define bstrdup(str) strdup(str)
 
 #include "fd_plugins.h"
-#include "api.h"
+#include "exch_api.h"
 
 #if defined(HAVE_WIN32)
-#include "win32/winapi.h"
+#include "winapi.h"
 #include "winhost.h"
 #else
 #include "host.h"
@@ -120,7 +110,7 @@ typedef int64_t   boffset_t;
 
 struct exchange_fd_context_t;
 
-#include "node.h"
+#include "exch_node.h"
 
 struct exchange_fd_context_t {
    struct bpContext *bpContext;
@@ -151,6 +141,7 @@ static inline WCHAR *towcharstring(char *src)
    return tmp;
 }
 
+#define safe_delete(buf) if (buf) { delete buf; buf=NULL; }
 
 extern bFuncs *bfuncs;
 extern bInfo  *binfo;
